@@ -7,7 +7,7 @@ use File::stat;
 use ExtUtils::Manifest qw(maniskip);
 $ExtUtils::Manifest::Quiet = 1;
 
-our $VERSION = '0.98';
+our $VERSION = '1.00';
 $VERSION =~ s/_//; ## no critic
 
 our $RespectManiskip = 1;  # for Test::Kwalitee and its friends
@@ -26,12 +26,10 @@ sub analyse {
 
     # Respect no_index if possible
     my $no_index_re = $class->_make_no_index_regex($me);
-    my $maniskip_file = "$distdir/MANIFEST.SKIP";
-    my $has_maniskip = -f $maniskip_file;
-    my $maniskip = maniskip($maniskip_file);
+    my $maniskip = $class->_make_maniskip($me, $distdir);
 
     my (%files, %dirs);
-    my (@files_array, @dirs_array);
+    my (@files_array, @dirs_array, @files_to_be_skipped);
     my $size = 0;
     my $latest_mtime = 0;
     my @base_dirs;
@@ -45,7 +43,17 @@ sub analyse {
         (my $path = $name) =~ s!^\Q$distdir\E(?:/|$)!! or next;
         next if $path eq '';
         next if $seen{$path}++;
-        next if $RespectManiskip && $has_maniskip && $maniskip->($path);
+
+        if ($me->d->{is_local_distribution}) {
+            next if $path =~ m!/\.!;
+        }
+
+        if ($maniskip && $maniskip->($path)) {
+            next if $RespectManiskip;
+            push @files_to_be_skipped, $path;
+            if (-d $name) { $dirs{$path}{maniskip} = 1 }
+            else { $files{$path}{maniskip} = 1 }
+        }
 
         if (-d $name) {
             $dirs{$path} ||= {};
@@ -56,10 +64,6 @@ sub analyse {
             next;
         }
 
-        if ($me->d->{is_local_distribution}) {
-            next if $path =~ m!/\.!;
-        }
-
         if (my $stat = stat($name)) {
             $files{$path}{size} = $stat->size || 0;
             $size += $files{$path}{size};
@@ -75,13 +79,13 @@ sub analyse {
             $files{$path}{symlink} = 1;
         }
 
-        if (!-r $name) {
-            $files{$path}{unreadable} = 1;
+        if ($no_index_re && $path =~ qr/$no_index_re/) {
+            $files{$path}{no_index} = 1;
             next;
         }
 
-        if ($no_index_re && $path =~ qr/$no_index_re/) {
-            $files{$path}{no_index} = 1;
+        if (!-r $name) {
+            $files{$path}{unreadable} = 1;
             next;
         }
 
@@ -110,6 +114,10 @@ sub analyse {
         $me->d->{error}{symlinks} = join ',', @symlinks;
     }
 
+    if (@files_to_be_skipped) {
+        $me->d->{error}{no_files_to_be_skipped} = join ',', @files_to_be_skipped;
+    }
+
     $me->d->{base_dirs} = [sort @base_dirs] if @base_dirs;
     my $base_dirs_re = join '|', '', map {quotemeta "$_/"} @base_dirs;
 
@@ -204,6 +212,31 @@ sub _make_no_index_regex {
     return '(?:' . (join '|', @ignore) . ')';
 }
 
+sub _make_maniskip {
+    my ($class, $me, $distdir) = @_;
+
+    my $maniskip_file = "$distdir/MANIFEST.SKIP";
+    return unless -f $maniskip_file && -r _;
+
+    # ignore MANIFEST.SKIP if it has an invalid entry
+    my $maniskip_bak_file = "$maniskip_file.bak";
+    my $has_maniskip_bak = -f $maniskip_bak_file;
+
+    my $maniskip = maniskip($maniskip_file);
+
+    my $maniskip_warning;
+    local $SIG{__WARN__} = sub { $maniskip_warning = shift; };
+    eval { $maniskip->(""); };
+    if ($@ or $maniskip_warning) {
+      $me->d->{error}{no_maniskip_error} = $@ || $maniskip_warning;
+      $maniskip = undef;
+    }
+    if (-f $maniskip_bak_file && !$has_maniskip_bak) {
+      unlink $maniskip_bak_file;  # probably generated by #include_default
+    }
+    $maniskip;
+}
+
 ##################################################################
 # Kwalitee Indicators
 ##################################################################
@@ -285,6 +318,16 @@ sub kwalitee_indicators {
             return "Any Changelog file was not found.";
         },
     },
+    {
+        name => 'no_files_to_be_skipped',
+        error => q{This distribution contains files that should be skipped by MANIFEST.SKIP.},
+        remedy => q{Fix MANIFEST.SKIP or use an authoring tool which respects MANIFEST.SKIP. Note that each entry in MANIFEST.SKIP is a regular expression. You may need to add appropriate meta characters not to ignore necessary stuff.},
+        code => sub {shift->{error}{no_files_to_be_skipped} ? 0 : 1},
+        details => sub {
+            my $d = shift;
+            return "The following files were found: ".$d->{error}{no_files_to_be_skipped};
+        },
+    },
     {
         name => 'no_symlinks',
         error => q{This distribution includes symbolic links (symlinks). This is bad, because there are operating systems that do not handle symlinks.},
@@ -345,6 +388,23 @@ sub kwalitee_indicators {
             return "<STDIN> was found in Build.PL" if $d->{stdin_in_build_pl};
         },
     },
+    {
+        name => 'no_maniskip_error',
+        error => q{This distribution's MANIFEST.SKIP has a problematic entry.},
+        is_extra => 1,
+        remedy => q{Fix the problematic entry.},
+        code => sub {
+            my $d = shift;
+            if ($d->{error}{no_maniskip_error}) {
+                return 0;
+            }
+            return 1;
+        },
+        details => sub {
+            my $d = shift;
+            return $d->{error}{no_maniskip_error};
+        },
+    },
 ];
 }
 
